@@ -26,5 +26,18 @@ export default route(function (/* { store, ssrContext } */) {
     history: createHistory(process.env.MODE === 'ssr' ? void 0 : process.env.VUE_ROUTER_BASE)
   })
 
+  % if auth:
+  Router.beforeEach(async (to, from) => {
+    const authenticatedUser = localStorage.authenticatedUser || 'null';
+    if (
+      authenticatedUser === 'null' &&
+      to.meta.requiresAuth &&
+      to.path !== '/login'
+    ) {
+      return '/login'
+    }
+  })
+  % endif
+
   return Router
 })
