@@ -67,7 +67,7 @@ def connect_to_server(ip_address: str, root: bool = False) -> Union[Connection,
     conn = Connection(
         host=f'{host}@{ip_address}',
         connect_kwargs={
-            "key_filename": f"{os.getenv('HOME')}/.ssh/id_ed25519.pub",
+            "key_filename": f"{os.getenv('HOME')}/.ssh/id_rsa.pub",
         },
         connect_timeout=6
     )
